==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/Input/vorbis/translations/vorbis_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis Module</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis Bestanden</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Over de Ogg Vorbis Audio Module</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Ogg Vorbis Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation>Broncode gebasseerd op het &apos;mq3 project&apos;</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Sample frequentie</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Input/vorbis/translations/vorbis_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis Module</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis Bestanden</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Over de Ogg Vorbis Audio Module</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Ogg Vorbis Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation>Broncode gebasseerd op het &apos;mq3 project&apos;</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Sample frequentie</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>
